@@ -10,7 +10,7 @@ class Controller(object):
     def on_quit(self, sender):
         raise NotImplementedError
 
-    def on_keybinding_activated(self, core=None, time=None):
+    def on_keybinding_activated(self, core, time):
         raise NotImplementedError
 
     def on_show_about(self, sender):
@@ -31,14 +31,23 @@ class Controller(object):
     def on_query_entry_activate(self, entry):
         raise NotImplementedError
         
-    def on_match_selected(self, treeview, match):
+    def on_treeview_cursor_changed(self, treeview):
         raise NotImplementedError
         
+    def on_match_selected(self, treeview, text, match_obj, event):
+        raise NotImplementedError
+    
+    def on_do_default_action(self, treeview, text, match_obj, event):
+        raise NotImplementedError
+     
+    def on_action_selected(self, treeview, text, action, event):
+        raise NotImplementedError
+     
     def on_clear_history(self, sender):
         raise NotImplementedError
     
     def on_history_match_selected(self, history, text, match):
         raise NotImplementedError
     
-    def on_window_resized(self, window, event):
+    def update_entry_icon (self, icon=None):
         raise NotImplementedError
\ No newline at end of file
